#version 330

uniform sampler2D diffuseY, diffuseG, diffuseR, diffuseB, diffuseBl, normalMap, specularMap, rust;
uniform float shininess = 80;
uniform float rusting = 0.2; 

in Data {
	vec3 eye;
	vec2 texCoord;
	vec3 l_dir;
    vec3 normal;
} DataIn;

out vec4 colorOut;

float perlinNoise(vec3 pos);

void main() {

	vec4 color = texture(diffuseY, DataIn.texCoord);

	// normalize both input vectors
	vec3 e = normalize(DataIn.eye);
	vec3 l = normalize(DataIn.l_dir);
    vec3 n = normalize(DataIn.normal);

	float intensity = max(dot(n, l), 0.0);

    float texSpecular = texture(specularMap, DataIn.texCoord).r;
	vec4 spec = vec4(0.0);
	// if the vertex is lit compute the specular color
	if (intensity > 0.0 ) {
		// compute the half vector
		vec3 h = normalize(l + e);	
		// compute the specular intensity
		float intSpec = max(dot(h,n), 0.0);
		// compute the specular term into spec
		spec = vec4(pow(intSpec,shininess)) * texSpecular;
	}


	colorOut = max(intensity * color + spec  + color * 0.5,0);
}

